@@ -20,10 +20,9 @@
 #ifndef menuinfo_h
 #define menuinfo_h
 
-
 #include <QList>
 
-#include <KShortcut>
+#include <QKeySequence>
 #include <KService>
 
 class MenuFile;
@@ -32,26 +31,37 @@ class MenuEntryInfo;
 class MenuInfo
 {
 public:
-    MenuInfo() {}
-    virtual ~MenuInfo() {}
+    MenuInfo()
+    {
+    }
+
+    virtual ~MenuInfo()
+    {
+    }
 };
 
 class MenuSeparatorInfo : public MenuInfo
 {
 public:
-    MenuSeparatorInfo() {}
+    MenuSeparatorInfo()
+    {
+    }
 };
 
 class MenuFolderInfo : public MenuInfo
 {
 public:
-    MenuFolderInfo() : dirty(false), hidden(false) { }
-    ~MenuFolderInfo() { qDeleteAll(subFolders); subFolders.clear(); }
+    MenuFolderInfo() : dirty(false)
+        , hidden(false)
+    {
+    }
+
+    ~MenuFolderInfo();
     // Add separator
-    void add(MenuSeparatorInfo *, bool initial=false);
+    void add(MenuSeparatorInfo *, bool initial = false);
 
     // Add sub menu
-    void add(MenuFolderInfo *, bool initial=false);
+    void add(MenuFolderInfo *, bool initial = false);
 
     // Remove sub menu (without deleting it)
     void take(MenuFolderInfo *);
@@ -81,30 +91,38 @@ public:
 
     void setCaption(const QString &_caption)
     {
-       if (_caption == caption) return;
-       caption = _caption;
-       setDirty();
+        if (_caption == caption) {
+            return;
+        }
+        caption = _caption;
+        setDirty();
     }
 
     void setIcon(const QString &_icon)
     {
-       if (_icon == icon) return;
-       icon = _icon;
-       setDirty();
+        if (_icon == icon) {
+            return;
+        }
+        icon = _icon;
+        setDirty();
     }
 
     void setGenericName(const QString &_description)
     {
-       if (_description == genericname) return;
-       genericname = _description;
-       setDirty();
+        if (_description == genericname) {
+            return;
+        }
+        genericname = _description;
+        setDirty();
     }
 
     void setComment(const QString &_comment)
     {
-       if (_comment == comment) return;
-       comment = _comment;
-       setDirty();
+        if (_comment == comment) {
+            return;
+        }
+        comment = _comment;
+        setDirty();
     }
 
     // Mark menu as dirty
@@ -120,7 +138,7 @@ public:
     void save(MenuFile *);
 
     // Search service by shortcut
-    KService::Ptr findServiceShortcut(const KShortcut&);
+    KService::Ptr findServiceShortcut(const QKeySequence &);
 
     // Set whether the entry is in active use (as opposed to in the clipboard/deleted)
     void setInUse(bool inUse);
@@ -143,27 +161,38 @@ public:
 class MenuEntryInfo : public MenuInfo
 {
 public:
-    explicit MenuEntryInfo(const KService::Ptr &_service, KDesktopFile *_df = 0)
-     : service(_service), m_desktopFile(_df),
-       shortcutLoaded(false), shortcutDirty(false), dirty(_df != 0), hidden(false)
+    explicit MenuEntryInfo(const KService::Ptr &_service, KDesktopFile *_df = nullptr)
+        : service(_service)
+        , m_desktopFile(_df)
+        , shortcutLoaded(false)
+        , shortcutDirty(false)
+        , dirty(_df != 0)
+        , hidden(false)
     {
-       caption = service->name();
-       description = service->genericName();
-       icon = service->icon();
+        caption = service->name();
+        description = service->genericName();
+        icon = service->icon();
     }
+
     ~MenuEntryInfo();
 
     void setCaption(const QString &_caption);
     void setDescription(const QString &_description);
     void setIcon(const QString &_icon);
 
-    QString menuId() const { return service->menuId(); }
+    QString menuId() const
+    {
+        return service->menuId();
+    }
 
-    QString file() const { return service->entryPath(); }
+    QString file() const
+    {
+        return service->entryPath();
+    }
 
-    KShortcut shortcut();
-    void setShortcut(const KShortcut &_shortcut);
-    bool isShortcutAvailable(const KShortcut &_shortcut);
+    QKeySequence shortcut();
+    void setShortcut(const QKeySequence &_shortcut);
+    bool isShortcutAvailable(const QKeySequence &_shortcut);
 
     void setDirty();
 
@@ -183,7 +212,7 @@ public:
     QString icon;
     KService::Ptr service;
     KDesktopFile *m_desktopFile;
-    KShortcut shortCut;
+    QKeySequence shortCut;
     bool shortcutLoaded;
     bool shortcutDirty;
     bool dirty;
