@@ -24,25 +24,26 @@
 
 #include <unistd.h>
 
+#include <QAction>
+#include <QApplication>
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QDir>
 #include <QDrag>
+#include <QDropEvent>
 #include <QHeaderView>
+#include <QIcon>
+#include <QInputDialog>
+#include <QMenu>
 #include <QPainter>
 #include <QRegExp>
-#include <QIcon>
-#include <QDropEvent>
-#include <QMenu>
-#include <QApplication>
-#include <QtDBus>
-#include <QSignalMapper>
+#include <QUrl>
 
-#include <QAction>
 #include <KActionCollection>
 #include <KBuildSycocaProgressDialog>
 #include "kmenuedit_debug.h"
 #include <KDesktopFile>
 #include <KIconLoader>
-#include <KInputDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KService>
@@ -50,7 +51,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KUrlMimeData>
-#include <KUrl>
 #include <KStringHandler>
 #include <QStandardPaths>
 
@@ -260,20 +260,14 @@ TreeView::TreeView(KActionCollection *ac, QWidget *parent)
     connect(m_ac->action(DELETE_ACTION_NAME), SIGNAL(triggered()), SLOT(del()));
 
     // listen for sorting
-    m_sortSignalMapper = new QSignalMapper(this);
     QAction *action = m_ac->action(SORT_BY_NAME_ACTION_NAME);
-    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
-    m_sortSignalMapper->setMapping(action, SortByName);
+    connect(action, &QAction::triggered, this, [this]() {sort(SortByName);});
     action = m_ac->action(SORT_BY_DESCRIPTION_ACTION_NAME);
-    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
-    m_sortSignalMapper->setMapping(action, SortByDescription);
+    connect(action, &QAction::triggered, this, [this]() {sort(SortByDescription);});
     action = m_ac->action(SORT_ALL_BY_NAME_ACTION_NAME);
-    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
-    m_sortSignalMapper->setMapping(action, SortAllByName);
+    connect(action, &QAction::triggered, this, [this]() {sort(SortAllByName);});
     action = m_ac->action(SORT_ALL_BY_DESCRIPTION_ACTION_NAME);
-    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
-    m_sortSignalMapper->setMapping(action, SortAllByDescription);
-    connect(m_sortSignalMapper, SIGNAL(mapped(const int)), this, SLOT(sort(const int)));
+    connect(action, &QAction::triggered, this, [this]() {sort(SortAllByDescription);});
 
     // connect moving up/down actions
     connect(m_ac->action(MOVE_UP_ACTION_NAME), &QAction::triggered, this, &TreeView::moveUpItem);
@@ -615,10 +609,12 @@ void TreeView::selectMenuEntry(const QString &menuEntry)
 
 void TreeView::itemSelected(QTreeWidgetItem *item)
 {
-    // ensure the item is visible as selected
-    setItemSelected(item, true);
+    if (item) {
+        // ensure the item is visible as selected
+        item->setSelected(true);
+    }
 
-    TreeItem *_item = static_cast<TreeItem *>(item);
+    TreeItem *_item = item ? static_cast<TreeItem *>(item) : nullptr;
     TreeItem *parentItem = nullptr;
     bool selected = false;
     bool dselected = false;
@@ -637,21 +633,23 @@ void TreeView::itemSelected(QTreeWidgetItem *item)
         m_ac->action(DELETE_ACTION_NAME)->setEnabled(selected && !dselected);
     }
 
-    m_ac->action(SORT_BY_NAME_ACTION_NAME)->setEnabled(selected && _item->isDirectory() && (_item->childCount() > 0));
+    m_ac->action(SORT_BY_NAME_ACTION_NAME)->setEnabled(selected && _item && _item->isDirectory() && (_item->childCount() > 0));
     m_ac->action(SORT_BY_DESCRIPTION_ACTION_NAME)->setEnabled(m_ac->action(SORT_BY_NAME_ACTION_NAME)->isEnabled());
 
-    m_ac->action(MOVE_UP_ACTION_NAME)->setEnabled(selected && (parentItem->indexOfChild(_item) > 0));
-    m_ac->action(MOVE_DOWN_ACTION_NAME)->setEnabled(selected && (parentItem->indexOfChild(_item) < parentItem->childCount() - 1));
+    m_ac->action(MOVE_UP_ACTION_NAME)->setEnabled(_item && selected && (parentItem->indexOfChild(_item) > 0));
+    m_ac->action(MOVE_DOWN_ACTION_NAME)->setEnabled(_item && selected && (parentItem->indexOfChild(_item) < parentItem->childCount() - 1));
 
     if (!item) {
         emit disableAction();
         return;
     }
 
-    if (_item->isDirectory()) {
-        emit entrySelected(_item->folderInfo());
-    } else {
-        emit entrySelected(_item->entryInfo());
+    if (_item) {
+        if (_item->isDirectory()) {
+            emit entrySelected(_item->folderInfo());
+        } else {
+            emit entrySelected(_item->entryInfo());
+        }
     }
 }
 
@@ -709,7 +707,7 @@ void TreeView::startDrag(Qt::DropActions supportedActions)
     }
 
     QDrag *drag = new QDrag(this);
-    int iconSize = KIconLoader::global()->currentSize(KIconLoader::Small);
+    const int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize);
     drag->setPixmap(selectedItem()->icon(0).pixmap(iconSize, iconSize));
     drag->setMimeData(data);
     drag->exec(supportedActions, Qt::MoveAction);
@@ -812,11 +810,11 @@ bool TreeView::dropMimeData(QTreeWidgetItem *item, int index, const QMimeData *d
 
     if (!data->hasFormat(QLatin1String(s_internalMimeType))) {
         // External drop
-        if (!KUrl::List::canDecode(data)) {
+        if (!data->hasUrls()) {
             return false;
         }
 
-        KUrl::List urls = KUrl::List::fromMimeData(data);
+        QList<QUrl> urls = KUrlMimeData::urlsFromMimeData(data);
         if (urls.isEmpty() || !urls[0].isLocalFile()) {
             return false;
         }
@@ -1022,8 +1020,8 @@ void TreeView::newsubmenu()
     TreeItem *item = (TreeItem *)selectedItem();
 
     bool ok;
-    QString caption = KInputDialog::getText(i18n("New Submenu"),
-                                            i18n("Submenu name:"), QString(), &ok, this);
+    QString caption = QInputDialog::getText(this, i18n("New Submenu"), i18n("Submenu name:"),
+                                            QLineEdit::Normal, QString(), &ok);
 
     if (!ok) {
         return;
@@ -1090,8 +1088,8 @@ void TreeView::newitem()
     TreeItem *item = (TreeItem *)selectedItem();
 
     bool ok;
-    QString caption = KInputDialog::getText(i18n("New Item"),
-                                            i18n("Item name:"), QString(), &ok, this);
+    QString caption = QInputDialog::getText(this, i18n("New Item"), i18n("Item name:"),
+                                            QLineEdit::Normal, QString(), &ok);
 
     if (!ok) {
         return;
@@ -1361,7 +1359,7 @@ void TreeView::paste()
 
 /**
  * This slot is called from the signal mapper to sort children contained in an item.
- * This item is determinated according to the chosen sort type.
+ * This item is determined according to the chosen sort type.
  *
  * @brief Determine which item is to sort, and do it.
  * @param sortCmd Sort type.
@@ -1373,16 +1371,20 @@ void TreeView::sort(const int sortCmd)
     TreeItem *itemToSort;
     if (sortType == SortByName || sortType == SortByDescription) {
         itemToSort = static_cast<TreeItem *>(selectedItem());
+        sortItem(itemToSort, sortType);
     } else if (sortType == SortAllByDescription) {
         sortType = SortByDescription;
-        itemToSort = static_cast<TreeItem *>(invisibleRootItem());
+        for (int i = 0; i < topLevelItemCount(); ++i) {
+            itemToSort = static_cast<TreeItem *>(topLevelItem(i));
+            sortItem(itemToSort, sortType);
+        }
     } else { /* if (sortType == SortAllByName) */
         sortType = SortByName;
-        itemToSort = static_cast<TreeItem *>(invisibleRootItem());
+        for (int i = 0; i < topLevelItemCount(); ++i) {
+            itemToSort = static_cast<TreeItem *>(topLevelItem(i));
+            sortItem(itemToSort, sortType);
+        }
     }
-
-    // proceed to the sorting
-    sortItem(itemToSort, sortType);
 }
 
 /**
@@ -1883,7 +1885,7 @@ QVariant MenuItemMimeData::retrieveData(const QString &mimeType, QVariant::Type
     Q_UNUSED(type);
 
     if (m_item && mimeType == QLatin1String(s_internalMimeType)) {
-        return qVariantFromValue<TreeItem *>(m_item);
+        return QVariant::fromValue<TreeItem *>(m_item);
     }
 
     return QVariant();
